import{_ as e,n as s,h as a,T as d}from"./c.2c9aeedd.js";import"./c.a3456430.js";import"./index-9a842255.js";let l=class extends a{render(){return d`
      <esphome-process-dialog
        heading="Update All"
        .type=${"update-all"}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};l=e([s("esphome-update-all-dialog")],l);
